Index: chrome/browser/extensions/extension_function.h |
diff --git a/chrome/browser/extensions/extension_function.h b/chrome/browser/extensions/extension_function.h |
index ec84ddf43e41b958ac7031ae9c7a4f6991b2e5b9..e6ffdc29e8093137b979880990d2e60827ab2640 100644 |
--- a/chrome/browser/extensions/extension_function.h |
+++ b/chrome/browser/extensions/extension_function.h |
@@ -108,8 +108,11 @@ class ExtensionFunction |
// Specifies the raw arguments to the function, as a JSON value. |
virtual void SetArgs(const base::ListValue* args); |
- // Retrieves the results of the function as a Value. |
- const base::Value* GetResultValue(); |
+ // Sets a single Value as the results of the function. |
+ void SetSingleResult(base::Value* result); |
+ |
+ // Retrieves the results of the function as a ListValue. |
+ const base::ListValue* GetResultsListValue(); |
Aaron Boodman
2012/07/09 04:39:31
Kinda weird to include ListValue in name of method
Matt Tytel
2012/07/10 18:50:45
Done.
|
// Retrieves any error string from the function. |
virtual const std::string GetError(); |
@@ -207,9 +210,9 @@ class ExtensionFunction |
// The arguments to the API. Only non-null if argument were specified. |
scoped_ptr<base::ListValue> args_; |
- // The result of the API. This should be populated by the derived class before |
- // SendResponse() is called. |
- scoped_ptr<base::Value> result_; |
+ // The results of the API. This should be populated by the derived class |
+ // before SendResponse() is called. |
+ scoped_ptr<base::ListValue> results_; |
// Any detailed error from the API. This should be populated by the derived |
// class before Run() returns. |